@@ -1,30 +1,49 @@
 # !/usr/bin/env python
 # -*-coding:utf-8 -*-
 # Author     ：Campanula 梦芸 何
+import traceback
 from typing import Iterable, Union, List, Any, Tuple, Dict, Optional
 
-import pymysql
-from pymysql import Connection
-from pymysql.cursors import DictCursor
+# from MySQLdb import Connection
+# from MySQLdb.cursors import DictCursor
+
+# import pymysql
+# from pymysql import Connection
+# from pymysql.cursors import DictCursor
 
 from anduin.common import ENGINE_MYSQL, dbg, get_obj_name
 from anduin.frames.client_base import ClientBase
 from anduin.parser.sql_parser import Parser
+# import MySQLdb
+import pymysql
+from pymysql.cursors import DictCursor as pymysql_dict_cursor
+from MySQLdb.cursors import DictCursor as mysqldb_dict_cursor
+import MySQLdb
 
 
 class MySQLClient(ClientBase):
     def __init__(self, *args):
         super().__init__(*args)
+        print(self.db_engine)
+        dict_cursor = None
+        engine = None
+        if self.db_engine == 'pymysql':
+            self.dict_cursor = pymysql_dict_cursor
+            self.engine = pymysql
+        else:
+            self.dict_cursor = mysqldb_dict_cursor
+            self.engine = MySQLdb
+        print(self.engine.__name__)
         self.db = self.connect_db()
         self._tables = {}
         self._load_tables()
 
-    def connect_db(self) -> Union[Connection, None]:
+    def connect_db(self):
         '''
         连接数据库，不需要手动调用
         '''
         try:
-            res = pymysql.connect(host=self._host, user=self._user, password=self._psw, database=self._dbname,
+            res = self.engine.connect(host=self._host, user=self._user, password=self._psw, database=self._dbname,
                                   charset=self._charset, port=self._port,
                                   connect_timeout=self.time_out)
             dbg('连接创建成功', get_obj_name(self))
@@ -41,7 +60,7 @@ class MySQLClient(ClientBase):
             字段2:(....)
         }
         '''
-        sql = 'show fields from ' + tablename+''
+        sql = 'show fields from ' + tablename + ''
         res = self.query(sql, show_sql=False)
         if isinstance(res, Iterable):
             self._tables[tablename] = dict(zip(list(map(lambda x: x[0], res)), res))
@@ -55,10 +74,7 @@ class MySQLClient(ClientBase):
         res = self.query(sql, show_sql)
         tables = list(map(lambda x: x[0], res))
         for table in tables:
-            if '-' not in self._dbname:
-                table_name = self._dbname + '.' + table
-            else:
-                table_name = table
+            table_name = table
             self.load_an_table(table_name)
             # self._tables[table_name] = r
 
@@ -66,6 +82,7 @@ class MySQLClient(ClientBase):
         '''
         commit本次事务
         '''
+        # print('commit')
         self.db.commit()
 
     def query(self, sql: str, show_sql=False, sql_params=None, return_dict=False):
@@ -85,12 +102,14 @@ class MySQLClient(ClientBase):
         else:
             dummy_sql = sql
         if return_dict is True:
-            cursor = self.db.cursor(DictCursor)
+            cursor = self.db.cursor(self.dict_cursor)
         else:
             cursor = self.db.cursor()
+        # print('get_cursor')
         if show_sql is True:
             dbg('sql_id', id(self), dummy_sql)
         try:
+            # print('xxxx')
             if sql_params is not None:
                 cursor.execute(sql, tuple(sql_params))
             else:
@@ -98,6 +117,7 @@ class MySQLClient(ClientBase):
             self.update_last_execute_time()
             results = cursor.fetchall()
         except Exception as e:
+            traceback.print_exc()
             dbg('<--------DBERROR-------->')
             dbg(dummy_sql)
             dbg('execute fail!', str(e))
@@ -155,13 +175,22 @@ class MySQLClient(ClientBase):
         """
 
         if table not in self._tables:
-            self.load_an_table(table)
+            r = self.load_an_table(table)
+            if isinstance(r, Exception):
+                dbg('ERROR', r)
+                return r
 
         if fields[0] == '*' and len(fields) == 1:
             fieldList = list(self._tables[table].keys())
             fields = fieldList
+        else:
+            for field_name in fields:
+                if field_name not in self._tables[table].keys():
+                    dbg(field_name, 'not in ', table)
+                    return
 
-        sql, sql_params = Parser.find_info(table, conditions, or_cond, fields, None, order, None, for_update)
+        sql, sql_params = Parser.find_info(table, conditions, or_cond, fields, None, order, None, for_update,
+                                           table_fields=self._tables[table].keys())
         if sql is None:
             return
 
@@ -209,13 +238,22 @@ class MySQLClient(ClientBase):
         """
 
         if table not in self._tables:
-            self.load_an_table(table)
+            r = self.load_an_table(table)
+            if isinstance(r, Exception):
+                dbg('ERROR', r)
+                return r
 
         if fields[0] == '*' and len(fields) == 1:
             fieldList = list(self._tables[table].keys())
             fields = fieldList
+        else:
+            for field_name in fields:
+                if field_name not in self._tables[table].keys():
+                    dbg(field_name, 'not in ', table)
+                    return
 
-        sql, sql_params = Parser.find_info(table, conditions, or_cond, fields, group, order, limit, for_update)
+        sql, sql_params = Parser.find_info(table, conditions, or_cond, fields, group, order, limit, for_update,
+                                           table_fields=self._tables[table].keys())
         if sql is None:
             return
         #
@@ -241,7 +279,15 @@ class MySQLClient(ClientBase):
            show_sql:是否展示sql内容
                 默认False，开启后将会显示此次执行的sql内容并写入日志
         '''
-        sql, sql_params = Parser.insert_parser(table, content)
+        if table not in self._tables:
+            r = self.load_an_table(table)
+            if isinstance(r, Exception):
+                dbg('ERROR', r)
+                return r
+
+        sql, sql_params = Parser.insert_parser(table, content, table_fields=self._tables[table].keys())
+        if sql is None:
+            return
         r = self.query(sql, show_sql, sql_params)
         return r
 
@@ -269,12 +315,25 @@ class MySQLClient(ClientBase):
             show_sql:是否展示sql内容
                 默认False，开启后将会显示此次执行的sql内容并写入日志
         """
-        sql, sql_params = Parser.update_parser(table, conditions, or_cond, params)
+
+        # print(self._tables)
+        if table not in self._tables:
+            r = self.load_an_table(table)
+            if isinstance(r, Exception):
+                dbg('ERROR', r)
+                return r
+
+        # print(self._tables)
+        # print(self._tables[table])
+        # print(self._tables[table].keys())
+
+        sql, sql_params = Parser.update_parser(table, conditions, or_cond, params, table_fields=self._tables[table].keys())
         r = self.query(sql, show_sql, sql_params)
         # dbg('自动提交完毕')
         return r
 
-    def delete(self, table: str, conditions: List[Tuple], or_cond: Union[List[Tuple], None] = None, show_sql: bool = False):
+    def delete(self, table: str, conditions: List[Tuple], or_cond: Union[List[Tuple], None] = None,
+               show_sql: bool = False):
         '''
         删除数据
         :params
@@ -292,17 +351,17 @@ class MySQLClient(ClientBase):
         '''
 
         sql = 'delete from %s where  ' % table
-        sql, sql_params = Parser.bind_conditions(sql, conditions, or_cond)
+        sql, sql_params = Parser.bind_conditions(sql, conditions, or_cond, table_fields=self._tables[table].keys())
         #  #
         r = self.query(sql, show_sql, sql_params)
         return r
 
-    def drop_table(self,tablename:str,show_sql=False):
+    def drop_table(self, tablename: str, show_sql=False):
         '''
         删除数据表
         '''
-        sql = 'drop table if exists %s'%tablename
-        r = self.query(sql,show_sql=show_sql)
+        sql = 'drop table if exists %s' % tablename
+        r = self.query(sql, show_sql=show_sql)
         return r
 
     def show_database(self):
